# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proio/model/lcio/lcio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proio/model/lcio/lcio.proto',
  package='proio.model.lcio',
  syntax='proto3',
  serialized_options=_b('\n\013proio.modelB\004LcioZ\004lcio'),
  serialized_pb=_b('\n\x1bproio/model/lcio/lcio.proto\x12\x10proio.model.lcio\"\x1a\n\tIntParams\x12\r\n\x05\x61rray\x18\x01 \x03(\x05\"\x1c\n\x0b\x46loatParams\x12\r\n\x05\x61rray\x18\x01 \x03(\x02\"\x1d\n\x0cStringParams\x12\r\n\x05\x61rray\x18\x01 \x03(\t\"\x90\x03\n\x06Params\x12\x30\n\x04ints\x18\x01 \x03(\x0b\x32\".proio.model.lcio.Params.IntsEntry\x12\x34\n\x06\x66loats\x18\x02 \x03(\x0b\x32$.proio.model.lcio.Params.FloatsEntry\x12\x36\n\x07strings\x18\x03 \x03(\x0b\x32%.proio.model.lcio.Params.StringsEntry\x1aH\n\tIntsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.proio.model.lcio.IntParams:\x02\x38\x01\x1aL\n\x0b\x46loatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.proio.model.lcio.FloatParams:\x02\x38\x01\x1aN\n\x0cStringsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.proio.model.lcio.StringParams:\x02\x38\x01\"\\\n\nParticleID\x12\x12\n\nlikelihood\x18\x01 \x01(\x02\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x0b\n\x03PDG\x18\x03 \x01(\x05\x12\x0f\n\x07\x61lgType\x18\x04 \x01(\x05\x12\x0e\n\x06params\x18\x05 \x03(\x02\"\xdd\x01\n\nMCParticle\x12\x0f\n\x07parents\x18\x01 \x03(\x04\x12\x10\n\x08\x63hildren\x18\x02 \x03(\x04\x12\x0b\n\x03PDG\x18\x03 \x01(\x05\x12\x0e\n\x06vertex\x18\x04 \x03(\x01\x12\x0c\n\x04time\x18\x05 \x01(\x02\x12\t\n\x01p\x18\x06 \x03(\x01\x12\x0c\n\x04mass\x18\x07 \x01(\x01\x12\x0e\n\x06\x63harge\x18\x08 \x01(\x02\x12\x11\n\tPEndPoint\x18\t \x03(\x01\x12\x0c\n\x04spin\x18\n \x03(\x02\x12\x11\n\tcolorFlow\x18\x0b \x03(\x05\x12\x11\n\tgenStatus\x18\x0c \x01(\x05\x12\x11\n\tsimStatus\x18\r \x01(\r\"\x96\x01\n\rSimTrackerHit\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0b\n\x03pos\x18\x03 \x03(\x01\x12\x0c\n\x04\x45\x44\x65p\x18\x04 \x01(\x02\x12\x0c\n\x04time\x18\x05 \x01(\x02\x12\n\n\x02mc\x18\x06 \x01(\x04\x12\t\n\x01p\x18\x07 \x03(\x02\x12\x12\n\npathLength\x18\x08 \x01(\x02\x12\x0f\n\x07quality\x18\t \x01(\x05\"N\n\x0eTrackerRawData\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x05\x12\x0c\n\x04\x41\x44\x43s\x18\x04 \x03(\r\"N\n\x0bTrackerData\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x02\x12\x0f\n\x07\x63harges\x18\x04 \x03(\x02\"\xa5\x01\n\nTrackerHit\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03pos\x18\x04 \x03(\x01\x12\x0b\n\x03\x63ov\x18\x05 \x03(\x01\x12\x0c\n\x04\x45\x44\x65p\x18\x06 \x01(\x02\x12\x0f\n\x07\x45\x44\x65pErr\x18\x07 \x01(\x02\x12\x0c\n\x04time\x18\x08 \x01(\x02\x12\x0f\n\x07quality\x18\t \x01(\x05\x12\x0f\n\x07rawHits\x18\n \x03(\x04\"y\n\x0cTrackerPulse\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x02\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x02\x12\x0b\n\x03\x63ov\x18\x05 \x03(\x02\x12\x0f\n\x07quality\x18\x06 \x01(\x05\x12\x0b\n\x03TPC\x18\x07 \x01(\x04\"\xcb\x01\n\x0fTrackerHitPlane\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03pos\x18\x04 \x03(\x01\x12\t\n\x01U\x18\x05 \x03(\x02\x12\t\n\x01V\x18\x06 \x03(\x02\x12\n\n\x02\x64U\x18\x07 \x01(\x02\x12\n\n\x02\x64V\x18\x08 \x01(\x02\x12\x0c\n\x04\x45\x44\x65p\x18\t \x01(\x02\x12\x0f\n\x07\x45\x44\x65pErr\x18\n \x01(\x02\x12\x0c\n\x04time\x18\x0b \x01(\x02\x12\x0f\n\x07quality\x18\x0c \x01(\x05\x12\x0f\n\x07rawHits\x18\r \x03(\x04\"\xcc\x01\n\x13TrackerHitZCylinder\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03pos\x18\x04 \x03(\x01\x12\x0e\n\x06\x63\x65nter\x18\x05 \x03(\x02\x12\r\n\x05\x64RPhi\x18\x06 \x01(\x02\x12\n\n\x02\x64Z\x18\x07 \x01(\x02\x12\x0c\n\x04\x45\x44\x65p\x18\x08 \x01(\x02\x12\x0f\n\x07\x45\x44\x65pErr\x18\t \x01(\x02\x12\x0c\n\x04time\x18\n \x01(\x02\x12\x0f\n\x07quality\x18\x0b \x01(\x05\x12\x0f\n\x07rawHits\x18\x0c \x03(\x04\"\xbc\x02\n\x05Track\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x63hi2\x18\x02 \x01(\x02\x12\x0b\n\x03NDF\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x45\x64x\x18\x04 \x01(\x02\x12\x0f\n\x07\x64\x45\x64xErr\x18\x05 \x01(\x02\x12\x0e\n\x06radius\x18\x06 \x01(\x02\x12\x12\n\nsubDetHits\x18\x07 \x03(\x05\x12\x32\n\x06states\x18\x08 \x03(\x0b\x32\".proio.model.lcio.Track.TrackState\x12\x0c\n\x04hits\x18\t \x03(\x04\x12\x0e\n\x06tracks\x18\n \x03(\x04\x1au\n\nTrackState\x12\x0b\n\x03loc\x18\x01 \x01(\x05\x12\n\n\x02\x64\x30\x18\x02 \x01(\x02\x12\x0b\n\x03phi\x18\x03 \x01(\x02\x12\r\n\x05omega\x18\x04 \x01(\x02\x12\n\n\x02z0\x18\x05 \x01(\x02\x12\x0c\n\x04tanL\x18\x06 \x01(\x02\x12\x0b\n\x03\x63ov\x18\x07 \x03(\x02\x12\x0b\n\x03ref\x18\x08 \x03(\x02\"\xf1\x01\n\x11SimCalorimeterHit\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0e\n\x06\x65nergy\x18\x03 \x01(\x02\x12\x0b\n\x03pos\x18\x04 \x03(\x02\x12\x42\n\rcontributions\x18\x05 \x03(\x0b\x32+.proio.model.lcio.SimCalorimeterHit.Contrib\x1aY\n\x07\x43ontrib\x12\x12\n\nMCParticle\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nergy\x18\x02 \x01(\x02\x12\x0c\n\x04time\x18\x03 \x01(\x02\x12\x0b\n\x03PDG\x18\x04 \x01(\x05\x12\x0f\n\x07stepPos\x18\x05 \x03(\x02\"[\n\x11RawCalorimeterHit\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x11\n\tamplitude\x18\x03 \x01(\x05\x12\x11\n\ttimeStamp\x18\x04 \x01(\x05\"\x8b\x01\n\x0e\x43\x61lorimeterHit\x12\x0f\n\x07\x63\x65llID0\x18\x01 \x01(\x05\x12\x0f\n\x07\x63\x65llID1\x18\x02 \x01(\x05\x12\x0e\n\x06\x65nergy\x18\x03 \x01(\x02\x12\x11\n\tenergyErr\x18\x04 \x01(\x02\x12\x0c\n\x04time\x18\x05 \x01(\x02\x12\x0b\n\x03pos\x18\x06 \x03(\x02\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x0b\n\x03raw\x18\x08 \x01(\x04\"\x83\x02\n\x07\x43luster\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06\x65nergy\x18\x02 \x01(\x02\x12\x11\n\tenergyErr\x18\x03 \x01(\x02\x12\x0b\n\x03pos\x18\x04 \x03(\x02\x12\x0e\n\x06posErr\x18\x05 \x03(\x02\x12\r\n\x05theta\x18\x06 \x01(\x02\x12\x0b\n\x03phi\x18\x07 \x01(\x02\x12\x0e\n\x06\x64irErr\x18\x08 \x03(\x02\x12\r\n\x05shape\x18\t \x03(\x02\x12*\n\x04PIDs\x18\n \x03(\x0b\x32\x1c.proio.model.lcio.ParticleID\x12\x10\n\x08\x63lusters\x18\x0b \x03(\x04\x12\x0c\n\x04hits\x18\x0c \x03(\x04\x12\x0f\n\x07weights\x18\r \x03(\x02\x12\x12\n\nsubDetEnes\x18\x0e \x03(\x02\"\x84\x02\n\x0bRecParticle\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\t\n\x01p\x18\x02 \x03(\x02\x12\x0e\n\x06\x65nergy\x18\x03 \x01(\x02\x12\x0b\n\x03\x63ov\x18\x04 \x03(\x02\x12\x0c\n\x04mass\x18\x05 \x01(\x02\x12\x0e\n\x06\x63harge\x18\x06 \x01(\x02\x12\x0b\n\x03ref\x18\x07 \x03(\x02\x12*\n\x04PIDs\x18\x08 \x03(\x0b\x32\x1c.proio.model.lcio.ParticleID\x12\x0f\n\x07PIDUsed\x18\t \x01(\x05\x12\x15\n\rgoodnessOfPID\x18\n \x01(\x02\x12\x0c\n\x04recs\x18\x0b \x03(\x04\x12\x0e\n\x06tracks\x18\x0c \x03(\x04\x12\x10\n\x08\x63lusters\x18\r \x03(\x04\x12\x10\n\x08startVtx\x18\x0e \x01(\x04\"\x81\x01\n\x06Vertex\x12\x0f\n\x07primary\x18\x01 \x01(\x05\x12\x0f\n\x07\x61lgType\x18\x02 \x01(\x05\x12\x0c\n\x04\x63hi2\x18\x03 \x01(\x02\x12\x0c\n\x04prob\x18\x04 \x01(\x02\x12\x0b\n\x03pos\x18\x05 \x03(\x02\x12\x0b\n\x03\x63ov\x18\x06 \x03(\x02\x12\x0e\n\x06params\x18\x07 \x03(\x02\x12\x0f\n\x07recPart\x18\x08 \x01(\x04\"4\n\x08Relation\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x04\x12\n\n\x02to\x18\x02 \x01(\x04\x12\x0e\n\x06weight\x18\x03 \x01(\x02\x42\x19\n\x0bproio.modelB\x04LcioZ\x04lciob\x06proto3')
)




_INTPARAMS = _descriptor.Descriptor(
  name='IntParams',
  full_name='proio.model.lcio.IntParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='proio.model.lcio.IntParams.array', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=75,
)


_FLOATPARAMS = _descriptor.Descriptor(
  name='FloatParams',
  full_name='proio.model.lcio.FloatParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='proio.model.lcio.FloatParams.array', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=105,
)


_STRINGPARAMS = _descriptor.Descriptor(
  name='StringParams',
  full_name='proio.model.lcio.StringParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='proio.model.lcio.StringParams.array', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=136,
)


_PARAMS_INTSENTRY = _descriptor.Descriptor(
  name='IntsEntry',
  full_name='proio.model.lcio.Params.IntsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.model.lcio.Params.IntsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.lcio.Params.IntsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=381,
)

_PARAMS_FLOATSENTRY = _descriptor.Descriptor(
  name='FloatsEntry',
  full_name='proio.model.lcio.Params.FloatsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.model.lcio.Params.FloatsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.lcio.Params.FloatsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=459,
)

_PARAMS_STRINGSENTRY = _descriptor.Descriptor(
  name='StringsEntry',
  full_name='proio.model.lcio.Params.StringsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.model.lcio.Params.StringsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.model.lcio.Params.StringsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=539,
)

_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='proio.model.lcio.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ints', full_name='proio.model.lcio.Params.ints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floats', full_name='proio.model.lcio.Params.floats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strings', full_name='proio.model.lcio.Params.strings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARAMS_INTSENTRY, _PARAMS_FLOATSENTRY, _PARAMS_STRINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=539,
)


_PARTICLEID = _descriptor.Descriptor(
  name='ParticleID',
  full_name='proio.model.lcio.ParticleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='likelihood', full_name='proio.model.lcio.ParticleID.likelihood', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.ParticleID.type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PDG', full_name='proio.model.lcio.ParticleID.PDG', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algType', full_name='proio.model.lcio.ParticleID.algType', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='proio.model.lcio.ParticleID.params', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=633,
)


_MCPARTICLE = _descriptor.Descriptor(
  name='MCParticle',
  full_name='proio.model.lcio.MCParticle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parents', full_name='proio.model.lcio.MCParticle.parents', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='proio.model.lcio.MCParticle.children', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PDG', full_name='proio.model.lcio.MCParticle.PDG', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.lcio.MCParticle.vertex', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.MCParticle.time', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.lcio.MCParticle.p', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.lcio.MCParticle.mass', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.lcio.MCParticle.charge', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PEndPoint', full_name='proio.model.lcio.MCParticle.PEndPoint', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin', full_name='proio.model.lcio.MCParticle.spin', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='colorFlow', full_name='proio.model.lcio.MCParticle.colorFlow', index=10,
      number=11, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='genStatus', full_name='proio.model.lcio.MCParticle.genStatus', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simStatus', full_name='proio.model.lcio.MCParticle.simStatus', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=857,
)


_SIMTRACKERHIT = _descriptor.Descriptor(
  name='SimTrackerHit',
  full_name='proio.model.lcio.SimTrackerHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.SimTrackerHit.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.SimTrackerHit.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.SimTrackerHit.pos', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDep', full_name='proio.model.lcio.SimTrackerHit.EDep', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.SimTrackerHit.time', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mc', full_name='proio.model.lcio.SimTrackerHit.mc', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.lcio.SimTrackerHit.p', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pathLength', full_name='proio.model.lcio.SimTrackerHit.pathLength', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='proio.model.lcio.SimTrackerHit.quality', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=1010,
)


_TRACKERRAWDATA = _descriptor.Descriptor(
  name='TrackerRawData',
  full_name='proio.model.lcio.TrackerRawData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerRawData.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerRawData.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerRawData.time', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ADCs', full_name='proio.model.lcio.TrackerRawData.ADCs', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1090,
)


_TRACKERDATA = _descriptor.Descriptor(
  name='TrackerData',
  full_name='proio.model.lcio.TrackerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerData.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerData.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerData.time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charges', full_name='proio.model.lcio.TrackerData.charges', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1170,
)


_TRACKERHIT = _descriptor.Descriptor(
  name='TrackerHit',
  full_name='proio.model.lcio.TrackerHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerHit.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerHit.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.TrackerHit.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.TrackerHit.pos', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cov', full_name='proio.model.lcio.TrackerHit.cov', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDep', full_name='proio.model.lcio.TrackerHit.EDep', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDepErr', full_name='proio.model.lcio.TrackerHit.EDepErr', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerHit.time', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='proio.model.lcio.TrackerHit.quality', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rawHits', full_name='proio.model.lcio.TrackerHit.rawHits', index=9,
      number=10, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1338,
)


_TRACKERPULSE = _descriptor.Descriptor(
  name='TrackerPulse',
  full_name='proio.model.lcio.TrackerPulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerPulse.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerPulse.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerPulse.time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.lcio.TrackerPulse.charge', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cov', full_name='proio.model.lcio.TrackerPulse.cov', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='proio.model.lcio.TrackerPulse.quality', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TPC', full_name='proio.model.lcio.TrackerPulse.TPC', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1461,
)


_TRACKERHITPLANE = _descriptor.Descriptor(
  name='TrackerHitPlane',
  full_name='proio.model.lcio.TrackerHitPlane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerHitPlane.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerHitPlane.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.TrackerHitPlane.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.TrackerHitPlane.pos', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='U', full_name='proio.model.lcio.TrackerHitPlane.U', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='V', full_name='proio.model.lcio.TrackerHitPlane.V', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dU', full_name='proio.model.lcio.TrackerHitPlane.dU', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dV', full_name='proio.model.lcio.TrackerHitPlane.dV', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDep', full_name='proio.model.lcio.TrackerHitPlane.EDep', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDepErr', full_name='proio.model.lcio.TrackerHitPlane.EDepErr', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerHitPlane.time', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='proio.model.lcio.TrackerHitPlane.quality', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rawHits', full_name='proio.model.lcio.TrackerHitPlane.rawHits', index=12,
      number=13, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1667,
)


_TRACKERHITZCYLINDER = _descriptor.Descriptor(
  name='TrackerHitZCylinder',
  full_name='proio.model.lcio.TrackerHitZCylinder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.TrackerHitZCylinder.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.TrackerHitZCylinder.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.TrackerHitZCylinder.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.TrackerHitZCylinder.pos', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='center', full_name='proio.model.lcio.TrackerHitZCylinder.center', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dRPhi', full_name='proio.model.lcio.TrackerHitZCylinder.dRPhi', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dZ', full_name='proio.model.lcio.TrackerHitZCylinder.dZ', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDep', full_name='proio.model.lcio.TrackerHitZCylinder.EDep', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EDepErr', full_name='proio.model.lcio.TrackerHitZCylinder.EDepErr', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.TrackerHitZCylinder.time', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='proio.model.lcio.TrackerHitZCylinder.quality', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rawHits', full_name='proio.model.lcio.TrackerHitZCylinder.rawHits', index=11,
      number=12, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1874,
)


_TRACK_TRACKSTATE = _descriptor.Descriptor(
  name='TrackState',
  full_name='proio.model.lcio.Track.TrackState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='proio.model.lcio.Track.TrackState.loc', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d0', full_name='proio.model.lcio.Track.TrackState.d0', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phi', full_name='proio.model.lcio.Track.TrackState.phi', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='omega', full_name='proio.model.lcio.Track.TrackState.omega', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z0', full_name='proio.model.lcio.Track.TrackState.z0', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tanL', full_name='proio.model.lcio.Track.TrackState.tanL', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cov', full_name='proio.model.lcio.Track.TrackState.cov', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref', full_name='proio.model.lcio.Track.TrackState.ref', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2076,
  serialized_end=2193,
)

_TRACK = _descriptor.Descriptor(
  name='Track',
  full_name='proio.model.lcio.Track',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.Track.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chi2', full_name='proio.model.lcio.Track.chi2', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='NDF', full_name='proio.model.lcio.Track.NDF', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dEdx', full_name='proio.model.lcio.Track.dEdx', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dEdxErr', full_name='proio.model.lcio.Track.dEdxErr', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius', full_name='proio.model.lcio.Track.radius', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subDetHits', full_name='proio.model.lcio.Track.subDetHits', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='states', full_name='proio.model.lcio.Track.states', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='proio.model.lcio.Track.hits', index=8,
      number=9, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracks', full_name='proio.model.lcio.Track.tracks', index=9,
      number=10, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRACK_TRACKSTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=2193,
)


_SIMCALORIMETERHIT_CONTRIB = _descriptor.Descriptor(
  name='Contrib',
  full_name='proio.model.lcio.SimCalorimeterHit.Contrib',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='MCParticle', full_name='proio.model.lcio.SimCalorimeterHit.Contrib.MCParticle', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.lcio.SimCalorimeterHit.Contrib.energy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.SimCalorimeterHit.Contrib.time', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PDG', full_name='proio.model.lcio.SimCalorimeterHit.Contrib.PDG', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepPos', full_name='proio.model.lcio.SimCalorimeterHit.Contrib.stepPos', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2437,
)

_SIMCALORIMETERHIT = _descriptor.Descriptor(
  name='SimCalorimeterHit',
  full_name='proio.model.lcio.SimCalorimeterHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.SimCalorimeterHit.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.SimCalorimeterHit.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.lcio.SimCalorimeterHit.energy', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.SimCalorimeterHit.pos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contributions', full_name='proio.model.lcio.SimCalorimeterHit.contributions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SIMCALORIMETERHIT_CONTRIB, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2196,
  serialized_end=2437,
)


_RAWCALORIMETERHIT = _descriptor.Descriptor(
  name='RawCalorimeterHit',
  full_name='proio.model.lcio.RawCalorimeterHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.RawCalorimeterHit.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.RawCalorimeterHit.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='proio.model.lcio.RawCalorimeterHit.amplitude', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStamp', full_name='proio.model.lcio.RawCalorimeterHit.timeStamp', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2439,
  serialized_end=2530,
)


_CALORIMETERHIT = _descriptor.Descriptor(
  name='CalorimeterHit',
  full_name='proio.model.lcio.CalorimeterHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellID0', full_name='proio.model.lcio.CalorimeterHit.cellID0', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellID1', full_name='proio.model.lcio.CalorimeterHit.cellID1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.lcio.CalorimeterHit.energy', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energyErr', full_name='proio.model.lcio.CalorimeterHit.energyErr', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proio.model.lcio.CalorimeterHit.time', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.CalorimeterHit.pos', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.CalorimeterHit.type', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw', full_name='proio.model.lcio.CalorimeterHit.raw', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2533,
  serialized_end=2672,
)


_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='proio.model.lcio.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.Cluster.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.lcio.Cluster.energy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energyErr', full_name='proio.model.lcio.Cluster.energyErr', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.Cluster.pos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posErr', full_name='proio.model.lcio.Cluster.posErr', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theta', full_name='proio.model.lcio.Cluster.theta', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phi', full_name='proio.model.lcio.Cluster.phi', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirErr', full_name='proio.model.lcio.Cluster.dirErr', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='proio.model.lcio.Cluster.shape', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PIDs', full_name='proio.model.lcio.Cluster.PIDs', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clusters', full_name='proio.model.lcio.Cluster.clusters', index=10,
      number=11, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='proio.model.lcio.Cluster.hits', index=11,
      number=12, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weights', full_name='proio.model.lcio.Cluster.weights', index=12,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subDetEnes', full_name='proio.model.lcio.Cluster.subDetEnes', index=13,
      number=14, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2934,
)


_RECPARTICLE = _descriptor.Descriptor(
  name='RecParticle',
  full_name='proio.model.lcio.RecParticle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.model.lcio.RecParticle.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.lcio.RecParticle.p', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='proio.model.lcio.RecParticle.energy', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cov', full_name='proio.model.lcio.RecParticle.cov', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.lcio.RecParticle.mass', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.lcio.RecParticle.charge', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref', full_name='proio.model.lcio.RecParticle.ref', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PIDs', full_name='proio.model.lcio.RecParticle.PIDs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PIDUsed', full_name='proio.model.lcio.RecParticle.PIDUsed', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goodnessOfPID', full_name='proio.model.lcio.RecParticle.goodnessOfPID', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recs', full_name='proio.model.lcio.RecParticle.recs', index=10,
      number=11, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracks', full_name='proio.model.lcio.RecParticle.tracks', index=11,
      number=12, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clusters', full_name='proio.model.lcio.RecParticle.clusters', index=12,
      number=13, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startVtx', full_name='proio.model.lcio.RecParticle.startVtx', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2937,
  serialized_end=3197,
)


_VERTEX = _descriptor.Descriptor(
  name='Vertex',
  full_name='proio.model.lcio.Vertex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='proio.model.lcio.Vertex.primary', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algType', full_name='proio.model.lcio.Vertex.algType', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chi2', full_name='proio.model.lcio.Vertex.chi2', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prob', full_name='proio.model.lcio.Vertex.prob', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.lcio.Vertex.pos', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cov', full_name='proio.model.lcio.Vertex.cov', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='proio.model.lcio.Vertex.params', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recPart', full_name='proio.model.lcio.Vertex.recPart', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3200,
  serialized_end=3329,
)


_RELATION = _descriptor.Descriptor(
  name='Relation',
  full_name='proio.model.lcio.Relation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='proio.model.lcio.Relation.from', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='proio.model.lcio.Relation.to', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='proio.model.lcio.Relation.weight', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3331,
  serialized_end=3383,
)

_PARAMS_INTSENTRY.fields_by_name['value'].message_type = _INTPARAMS
_PARAMS_INTSENTRY.containing_type = _PARAMS
_PARAMS_FLOATSENTRY.fields_by_name['value'].message_type = _FLOATPARAMS
_PARAMS_FLOATSENTRY.containing_type = _PARAMS
_PARAMS_STRINGSENTRY.fields_by_name['value'].message_type = _STRINGPARAMS
_PARAMS_STRINGSENTRY.containing_type = _PARAMS
_PARAMS.fields_by_name['ints'].message_type = _PARAMS_INTSENTRY
_PARAMS.fields_by_name['floats'].message_type = _PARAMS_FLOATSENTRY
_PARAMS.fields_by_name['strings'].message_type = _PARAMS_STRINGSENTRY
_TRACK_TRACKSTATE.containing_type = _TRACK
_TRACK.fields_by_name['states'].message_type = _TRACK_TRACKSTATE
_SIMCALORIMETERHIT_CONTRIB.containing_type = _SIMCALORIMETERHIT
_SIMCALORIMETERHIT.fields_by_name['contributions'].message_type = _SIMCALORIMETERHIT_CONTRIB
_CLUSTER.fields_by_name['PIDs'].message_type = _PARTICLEID
_RECPARTICLE.fields_by_name['PIDs'].message_type = _PARTICLEID
DESCRIPTOR.message_types_by_name['IntParams'] = _INTPARAMS
DESCRIPTOR.message_types_by_name['FloatParams'] = _FLOATPARAMS
DESCRIPTOR.message_types_by_name['StringParams'] = _STRINGPARAMS
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['ParticleID'] = _PARTICLEID
DESCRIPTOR.message_types_by_name['MCParticle'] = _MCPARTICLE
DESCRIPTOR.message_types_by_name['SimTrackerHit'] = _SIMTRACKERHIT
DESCRIPTOR.message_types_by_name['TrackerRawData'] = _TRACKERRAWDATA
DESCRIPTOR.message_types_by_name['TrackerData'] = _TRACKERDATA
DESCRIPTOR.message_types_by_name['TrackerHit'] = _TRACKERHIT
DESCRIPTOR.message_types_by_name['TrackerPulse'] = _TRACKERPULSE
DESCRIPTOR.message_types_by_name['TrackerHitPlane'] = _TRACKERHITPLANE
DESCRIPTOR.message_types_by_name['TrackerHitZCylinder'] = _TRACKERHITZCYLINDER
DESCRIPTOR.message_types_by_name['Track'] = _TRACK
DESCRIPTOR.message_types_by_name['SimCalorimeterHit'] = _SIMCALORIMETERHIT
DESCRIPTOR.message_types_by_name['RawCalorimeterHit'] = _RAWCALORIMETERHIT
DESCRIPTOR.message_types_by_name['CalorimeterHit'] = _CALORIMETERHIT
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['RecParticle'] = _RECPARTICLE
DESCRIPTOR.message_types_by_name['Vertex'] = _VERTEX
DESCRIPTOR.message_types_by_name['Relation'] = _RELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntParams = _reflection.GeneratedProtocolMessageType('IntParams', (_message.Message,), dict(
  DESCRIPTOR = _INTPARAMS,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.IntParams)
  ))
_sym_db.RegisterMessage(IntParams)

FloatParams = _reflection.GeneratedProtocolMessageType('FloatParams', (_message.Message,), dict(
  DESCRIPTOR = _FLOATPARAMS,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.FloatParams)
  ))
_sym_db.RegisterMessage(FloatParams)

StringParams = _reflection.GeneratedProtocolMessageType('StringParams', (_message.Message,), dict(
  DESCRIPTOR = _STRINGPARAMS,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.StringParams)
  ))
_sym_db.RegisterMessage(StringParams)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), dict(

  IntsEntry = _reflection.GeneratedProtocolMessageType('IntsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARAMS_INTSENTRY,
    __module__ = 'proio.model.lcio.lcio_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.lcio.Params.IntsEntry)
    ))
  ,

  FloatsEntry = _reflection.GeneratedProtocolMessageType('FloatsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARAMS_FLOATSENTRY,
    __module__ = 'proio.model.lcio.lcio_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.lcio.Params.FloatsEntry)
    ))
  ,

  StringsEntry = _reflection.GeneratedProtocolMessageType('StringsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARAMS_STRINGSENTRY,
    __module__ = 'proio.model.lcio.lcio_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.lcio.Params.StringsEntry)
    ))
  ,
  DESCRIPTOR = _PARAMS,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.Params)
  ))
_sym_db.RegisterMessage(Params)
_sym_db.RegisterMessage(Params.IntsEntry)
_sym_db.RegisterMessage(Params.FloatsEntry)
_sym_db.RegisterMessage(Params.StringsEntry)

ParticleID = _reflection.GeneratedProtocolMessageType('ParticleID', (_message.Message,), dict(
  DESCRIPTOR = _PARTICLEID,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.ParticleID)
  ))
_sym_db.RegisterMessage(ParticleID)

MCParticle = _reflection.GeneratedProtocolMessageType('MCParticle', (_message.Message,), dict(
  DESCRIPTOR = _MCPARTICLE,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.MCParticle)
  ))
_sym_db.RegisterMessage(MCParticle)

SimTrackerHit = _reflection.GeneratedProtocolMessageType('SimTrackerHit', (_message.Message,), dict(
  DESCRIPTOR = _SIMTRACKERHIT,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.SimTrackerHit)
  ))
_sym_db.RegisterMessage(SimTrackerHit)

TrackerRawData = _reflection.GeneratedProtocolMessageType('TrackerRawData', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERRAWDATA,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerRawData)
  ))
_sym_db.RegisterMessage(TrackerRawData)

TrackerData = _reflection.GeneratedProtocolMessageType('TrackerData', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERDATA,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerData)
  ))
_sym_db.RegisterMessage(TrackerData)

TrackerHit = _reflection.GeneratedProtocolMessageType('TrackerHit', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERHIT,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerHit)
  ))
_sym_db.RegisterMessage(TrackerHit)

TrackerPulse = _reflection.GeneratedProtocolMessageType('TrackerPulse', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERPULSE,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerPulse)
  ))
_sym_db.RegisterMessage(TrackerPulse)

TrackerHitPlane = _reflection.GeneratedProtocolMessageType('TrackerHitPlane', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERHITPLANE,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerHitPlane)
  ))
_sym_db.RegisterMessage(TrackerHitPlane)

TrackerHitZCylinder = _reflection.GeneratedProtocolMessageType('TrackerHitZCylinder', (_message.Message,), dict(
  DESCRIPTOR = _TRACKERHITZCYLINDER,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.TrackerHitZCylinder)
  ))
_sym_db.RegisterMessage(TrackerHitZCylinder)

Track = _reflection.GeneratedProtocolMessageType('Track', (_message.Message,), dict(

  TrackState = _reflection.GeneratedProtocolMessageType('TrackState', (_message.Message,), dict(
    DESCRIPTOR = _TRACK_TRACKSTATE,
    __module__ = 'proio.model.lcio.lcio_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.lcio.Track.TrackState)
    ))
  ,
  DESCRIPTOR = _TRACK,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.Track)
  ))
_sym_db.RegisterMessage(Track)
_sym_db.RegisterMessage(Track.TrackState)

SimCalorimeterHit = _reflection.GeneratedProtocolMessageType('SimCalorimeterHit', (_message.Message,), dict(

  Contrib = _reflection.GeneratedProtocolMessageType('Contrib', (_message.Message,), dict(
    DESCRIPTOR = _SIMCALORIMETERHIT_CONTRIB,
    __module__ = 'proio.model.lcio.lcio_pb2'
    # @@protoc_insertion_point(class_scope:proio.model.lcio.SimCalorimeterHit.Contrib)
    ))
  ,
  DESCRIPTOR = _SIMCALORIMETERHIT,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.SimCalorimeterHit)
  ))
_sym_db.RegisterMessage(SimCalorimeterHit)
_sym_db.RegisterMessage(SimCalorimeterHit.Contrib)

RawCalorimeterHit = _reflection.GeneratedProtocolMessageType('RawCalorimeterHit', (_message.Message,), dict(
  DESCRIPTOR = _RAWCALORIMETERHIT,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.RawCalorimeterHit)
  ))
_sym_db.RegisterMessage(RawCalorimeterHit)

CalorimeterHit = _reflection.GeneratedProtocolMessageType('CalorimeterHit', (_message.Message,), dict(
  DESCRIPTOR = _CALORIMETERHIT,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.CalorimeterHit)
  ))
_sym_db.RegisterMessage(CalorimeterHit)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), dict(
  DESCRIPTOR = _CLUSTER,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.Cluster)
  ))
_sym_db.RegisterMessage(Cluster)

RecParticle = _reflection.GeneratedProtocolMessageType('RecParticle', (_message.Message,), dict(
  DESCRIPTOR = _RECPARTICLE,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.RecParticle)
  ))
_sym_db.RegisterMessage(RecParticle)

Vertex = _reflection.GeneratedProtocolMessageType('Vertex', (_message.Message,), dict(
  DESCRIPTOR = _VERTEX,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.Vertex)
  ))
_sym_db.RegisterMessage(Vertex)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), dict(
  DESCRIPTOR = _RELATION,
  __module__ = 'proio.model.lcio.lcio_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.lcio.Relation)
  ))
_sym_db.RegisterMessage(Relation)


DESCRIPTOR._options = None
_PARAMS_INTSENTRY._options = None
_PARAMS_FLOATSENTRY._options = None
_PARAMS_STRINGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



import io
import pytest

import proio

def test_header1():
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        event = proio.Event()
        writer.push(event)
        writer.push(event)
        writer.flush()
        writer.push(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        reader.skip(0)
        assert(reader._bucket_header.nEvents == 2)
        reader.skip(2)
        assert(reader._bucket_header.nEvents == 1)
        reader.skip(1)
        assert(reader._bucket_header is None)

def test_push_update1():
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.push_metadata('key1', b'value1')
        writer.push_metadata('key2', b'value2')
        event = proio.Event()
        writer.push(event)
        writer.push_metadata('key2', b'value3')
        writer.push(event)
        writer.push_metadata('key1', b'value4')
        writer.push_metadata('key2', b'value5')
        writer.push(event)

    buf.seek(0, 0)
    with proio.Reader(fileobj = buf) as reader:
        event1 = next(reader)
        event2 = next(reader)
        event3 = next(reader)
        assert(event1.metadata['key1'] == b'value1')
        assert(event1.metadata['key2'] == b'value2')
        assert(event2.metadata['key1'] == b'value1')
        assert(event2.metadata['key2'] == b'value3')
        assert(event3.metadata['key1'] == b'value4')
        assert(event3.metadata['key2'] == b'value5')

    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.push(event1)
        writer.push(event2)
        writer.push(event3)

    buf.seek(0, 0)
    with proio.Reader(fileobj = buf) as reader:
        event1 = next(reader)
        event2 = next(reader)
        event3 = next(reader)
        assert(event1.metadata['key1'] == b'value1')
        assert(event1.metadata['key2'] == b'value2')
        assert(event2.metadata['key1'] == b'value1')
        assert(event2.metadata['key2'] == b'value3')
        assert(event3.metadata['key1'] == b'value4')
        assert(event3.metadata['key2'] == b'value5')




import gzip
import io
import lz4.frame
import struct

import google.protobuf.descriptor_pool as descriptor_pool

import proio.proto as proto

magic_bytes = [b'\xe1',
        b'\xc1',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00',
        b'\x00']

class Writer(object):
    """
    Writer for proio files
    
    This class can be used with the `with` statement.  A filename may be
    omitted in favor of specifying `fileobj`.

    :param string filename: name of output file to create or overwrite
    :param fileobj: file object to write to

    :example:
    
    .. code-block:: python

        with proio.Writer('output.proio') as writer:
            ...

    """

    def __init__(self, filename = None, fileobj = None):
        if filename is None:
            if fileobj is not None:
                self._stream_writer = fileobj
            else:
                self._stream_writer = io.BytesIO(b'')
        else:
            self._stream_writer = open(filename, 'wb')
            self._close_file = True

        self.bucket_dump_size = 0x1000000

        self._bucket_events = 0
        self._header = proto.BucketHeader()
        self._bucket = io.BytesIO(b'')
        self._written_fds = set()
        self._metadata = {}
        self.set_compression(proto.BucketHeader.GZIP)

    def __enter__(self):
        return self

    def __exit__(self, exception_type, exception_value, traceback):
        self.close()

    def close(self):
        """
        closes the file object assigned to the Writer.  This is automatically
        called at the end of a `with` statement.
        """
        self.flush()
        try:
            if self._close_file:
                self._stream_writer.close()
        except:
            pass

    def flush(self):
        """
        flushes all buffered data to the output file object.  This is
        automatically called at the end of a `with` statement.
        """
        if self._bucket_events == 0:
            return

        if self._comp == proto.BucketHeader.LZ4:
            bucket_bytes = lz4.frame.compress(self._bucket.getvalue())
        elif self._comp == proto.BucketHeader.GZIP:
            bucket_compressed = io.BytesIO(b'')
            with gzip.GzipFile(fileobj = bucket_compressed, mode = 'wb') as writer:
                writer.write(self._bucket.getvalue())
            bucket_bytes = bucket_compressed.getvalue()
        else:
            bucket_bytes = self._bucket.getvalue()

        self._bucket.seek(0, 0)
        self._bucket.truncate(0)

        self._header.nEvents = self._bucket_events
        self._header.bucketSize = len(bucket_bytes)
        self._header.compression = self._comp
        header_buf = self._header.SerializeToString()

        header_size = struct.pack("I", len(header_buf))

        for magic_byte in magic_bytes:
            self._stream_writer.write(magic_byte)
        self._stream_writer.write(header_size)
        self._stream_writer.write(header_buf)
        self._stream_writer.write(bucket_bytes)

        self._bucket_events = 0
        self._header = proto.BucketHeader()

    def set_compression(self, comp):
        """
        sets the compression type to use for future output buckets.

        :param comp: can be one of :attr:`proio.LZ4`, :attr:`proio.GZIP`, or
            :attr:`proio.UNCOMPRESSED`
        """
        self._comp = comp

    def push(self, event):
        """
        takes an event and serializes it into the output bucket.

        :param Event event: event to serialize to output
        """
        for key, value in event.metadata.items():
            if key not in self._metadata or self._metadata[key] != value:
                self.push_metadata(key, value)
                self._metadata[key] = value

        event._flush_cache()
        proto_buf = event._proto.SerializeToString()

        # add new protobuf FileDescriptors to the stream that are required to
        # describe event data
        new_fds = set()
        def add_fds_to_set(fd):
            for dep in fd.dependencies:
                add_fds_to_set(dep)
            if fd not in self._written_fds:
                new_fds.add(fd)
                self._written_fds.add(fd)
        for _, type_string in event._proto.type.items():
            add_fds_to_set(descriptor_pool.Default().FindMessageTypeByName(type_string).file)
        if len(new_fds) > 0:
            self.flush()
        for fd in new_fds:
            self._header.fileDescriptor.append(fd.serialized_pb)

        proto_size = struct.pack("I", len(proto_buf))

        self._bucket.write(proto_size)
        self._bucket.write(proto_buf)

        self._bucket_events += 1

        bucket_length = len(self._bucket.getvalue())
        if bucket_length > self.bucket_dump_size:
            self.flush()

    def push_metadata(self, key, value):
        """
        takes a human-readable string key and a byte string value and inserts
        it into the stream as metadata.  A reader will then assign these
        metadata to events that follow in the stream.

        :param string key: key
        :param bytes value: value
        """
        self.flush()
        self._header.metadata[key] = value



from .event import Event
from .reader import Reader
from .writer import Writer

__all__ = ['Event', 'Reader', 'Writer']

from .proto import BucketHeader

GZIP = BucketHeader.GZIP
LZ4 = BucketHeader.LZ4
UNCOMPRESSED = BucketHeader.NONE
